# Notebooks

```{toctree}
:maxdepth: 1

hub-cloud/init-local-instance
hub-cloud/connect-local-instance
hub-cloud/add-managed-storage
hub-cloud/test-bionty
hub-cloud/init-hosted-instance
hub-cloud/connect-hosted-instance
hub-cloud/keep-artifacts-local
hub-cloud/test-multi-session

hub-prod/test-cache-management
hub-prod/test-empty-init
hub-prod/test-import-modules
hub-prod/test-invalid-modules
hub-prod/test-insufficient-user-info
hub-prod/test-init-load-local-anonymously
hub-prod/test-connect-anonymously
hub-prod/test-sqlite-lock
hub-prod/test-cloud-sync

```
